.. _glossary:

Glossarium
==========

.. glossary::
   :sorted:

   Pyramid
     A `web framework <http://www.pylonsproject.org>`_.

   Github
     Op `Github <https://github.com>`__ plaatsen we onze :term:`git` 
     repositories. Voor toepassingen combineren we dit met Trac voor 
     projectopvolging, voor libraries die enkel voor het IT-team van belang
     zijn, gebruiken we de Github issue tracker.

   git
     Het versie controle systeem waar we bij voorkeur mee werken. 
     Zie `Progit <http://www.progit.org/>`__ voor een goeie uitleg.

   MMIS
     `Milieu Management Informatie Systemen <http://www.milieuinfo.be>`__. 
     Collega's van de Vlaamse Overheid die horen tot het departement van het 
     beleidsdomein LNE. Worden soms ook LNE of ACD genoemd. Zij zorgen voor de 
     hosting van onze toepassingen, servers, databanken, ... Waar mogelijk delen 
     we oplossingen.

   Jinja2
     `Jinja2 <http://jinja.pocoo.org>`__ is de templating taal die we gebruiken 
     voor onze python applicaties. De syntax lijkt vrij sterk op die van Django
     en werd ook overgenomen in `Twig <http://twig.org>`__, een PHP templating 
     taal.
